package org.mvel2.tests.core.res;

public class Member {
  private String name;
  private Integer age;

  public Member(String name, Integer age) {
    super();
    this.name = name;
    this.age = age;
  }

  public String getName() {
    return name;
  }

  public Integer getAge() {
    return age;
  }
}
